@@ -91,7 +91,7 @@ void Runner::command_delete(const vector<Token>& args)
             funcs.push_back(Lexer::get_string(*i));
         else if (i->type == kTokenVarname)
             vars.push_back(Lexer::get_string(*i));
-        else if (i->type == kTokenFilename || i->type == kTokenString)
+        else if (i->type == kTokenWord || i->type == kTokenString)
             files.push_back(Lexer::get_string(*i));
         else
             assert(0);
@@ -292,7 +292,7 @@ void Runner::command_plot(const vector<Token>& args, int ds)
         dd.push_back(ds);
     F_->view.change_view(hor, ver, dd);
     string filename;
-    if (args.back().type == kTokenFilename || args.back().type == kTokenString)
+    if (args.back().type == kTokenWord || args.back().type == kTokenString)
         filename = Lexer::get_string(args.back());
     F_->ui()->draw_plot(UserInterface::kRepaintImmediately,
                         filename.empty() ? NULL : filename.c_str());
@@ -436,43 +436,61 @@ void Runner::command_name_func(const vector<Token>& args, int ds)
 
 void Runner::command_assign_param(const vector<Token>& args, int ds)
 {
-    // args: Funcname Lname EVar
-    // args: (Dataset|Nop) (F|Z) Expr Lname EVar
-    string name = get_func(F_, ds, args.begin());
-    string param = (args.end()-2)->as_string();
-    const Token& var = *(args.end()-1);
-    F_->mgr.substitute_func_param(name, param, get_vm_from_token(var));
+    if (args[2].type == kTokenMult || args[1].type == kTokenNop) {
+        command_assign_all(args, ds);
+    } else {
+        // args: Funcname Lname EVar
+        // args: (Dataset|Nop) (F|Z) Expr Lname EVar
+        string name = get_func(F_, ds, args.begin());
+        string param = (args.end()-2)->as_string();
+        const Token& var = *(args.end()-1);
+        F_->mgr.substitute_func_param(name, param, get_vm_from_token(var));
+    }
     F_->mgr.use_parameters();
     F_->outdated_plot();
 }
 
 void Runner::command_assign_all(const vector<Token>& args, int ds)
 {
-    // args: (Dataset|Nop) (F|Z) '*' Lname Expr
+    // args: (Dataset|Nop) (F|Z|Nop) '*' Lname Expr
     assert(args[0].type == kTokenDataset || args[0].type == kTokenNop);
-    assert(args[1].type == kTokenUletter);
-    assert(args[2].type == kTokenMult);
+    assert(args[1].type == kTokenUletter || args[1].type == kTokenNop);
+    assert(args[2].type == kTokenMult || args[2].type == kTokenFuncname);
     assert(args[3].type == kTokenLname);
     assert(args[4].type == kTokenEVar);
     if (args[0].type == kTokenDataset)
         ds = args[0].value.i;
-    char c = *args[1].str;
     string param = args[3].as_string();
     VMData* vd = get_vm_from_token(args[4]);
-    const FunctionSum& fz = F_->dk.get_model(ds)->get_fz(c);
-    v_foreach (string, i, fz.names) {
-        if (contains_element(F_->mgr.find_function(*i)->tp()->fargs, param))
-            F_->mgr.substitute_func_param(*i, param, vd);
+    int cnt = 0;
+    if (args[1].type == kTokenUletter) {
+        char c = *args[1].str;
+        const FunctionSum& fz = F_->dk.get_model(ds)->get_fz(c);
+        v_foreach (string, i, fz.names) {
+            const Function *func = F_->mgr.find_function(*i);
+            if (contains_element(func->tp()->fargs, param)) {
+                F_->mgr.substitute_func_param(*i, param, vd);
+                cnt++;
+            }
+        }
+    } else {
+        string funcname = args[2].as_string().substr(1);
+        v_foreach (Function*, i, F_->mgr.functions()) {
+            if (match_glob((*i)->name.c_str(), funcname.c_str()) &&
+                    contains_element((*i)->tp()->fargs, param)) {
+                F_->mgr.substitute_func_param((*i)->name, param, vd);
+                cnt++;
+            }
+        }
     }
-    F_->mgr.use_parameters();
-    F_->outdated_plot();
+    if (F_->get_verbosity() >= 1)
+        F_->ui()->mesg(S(cnt) + " parameters substituted.");
 }
 
 void Runner::command_name_var(const vector<Token>& args, int ds)
 {
     assert(args.size() >= 2 && args[0].type == kTokenVarname);
     string name = Lexer::get_string(args[0]);
-    int pos;
     int n_args;
     if (args[1].as_string() == "copy") {
         assert(args.size() > 2);
@@ -486,14 +504,13 @@ void Runner::command_name_var(const vector<Token>& args, int ds)
             string param = args[n_args-1].as_string();
             orig_name = F_->mgr.find_function(func_name)->var_name(param);
         }
-        pos = F_->mgr.assign_var_copy(name, orig_name);
+        F_->mgr.assign_var_copy(name, orig_name);
     } else {
         assert(args.size() == 2 || args.size() == 4);
         VMData* vd = get_vm_from_token(args[1]);
-        pos = F_->mgr.make_variable(name, vd);
+        F_->mgr.make_variable(name, vd);
         n_args = 2;
     }
-    assert(F_->mgr.get_variable(pos)->name == name);
     F_->mgr.use_parameters();
     F_->outdated_plot(); // TODO: only for replacing old variable
 }
@@ -606,13 +623,18 @@ void Runner::command_load(const vector<Token>& args)
         F_->dk.data(dataset)->revert();
     } else { // read given file
         string format, options;
-        if (args.size() > 2) {
-            format = args[2].as_string();
+        vector<Token>::const_iterator it = args.begin() + 2;
+        if (it != args.end() && it->type == kTokenWord) {
+            filename += it->as_string();
+            ++it;
+        }
+        if (it != args.end()) {
+            format = it->as_string();
             // "_" means any format (useful for passing option decimal_comma)
             if (format == "_")
                 format.clear();
-            for (size_t i = 3; i < args.size(); ++i)
-                options += (i == 3 ? "" : " ") + args[i].as_string();
+            while (++it != args.end())
+                options += (options.empty() ? "" : " ") + it->as_string();
         }
         F_->dk.import_dataset(dataset, filename, format, options, F_, F_->mgr);
         if (F_->dk.count() == 1) {
@@ -789,14 +811,8 @@ void Runner::execute_command(Command& c, int ds)
             F_->dk.data(ds)->set_title(Lexer::get_string(c.args[0]));
             break;
         case kCmdAssignParam:
-            if (c.args[2].type == kTokenMult)
-                command_assign_all(c.args, ds);
-            else
-                command_assign_param(c.args, ds);
+            command_assign_param(c.args, ds);
             break;
-        //case kCmdAssignAll:
-        //    command_assign_all(c.args, ds);
-        //    break;
         case kCmdNameVar:
             command_name_var(c.args, ds);
             break;
