@@ -110,6 +110,10 @@
 using std::string;
 using std::vector;
 
+#if XYLIB_VERSION < 10500
+typedef shared_ptr<const xylib::DataSet> dataset_shared_ptr;
+#endif
+
 using fityk::FitManager;
 FFrame *frame = NULL;
 fityk::Full *ftk = NULL;
@@ -166,6 +170,7 @@ enum {
     ID_F_REDO                  ,
     ID_F_HISTORY               ,
     ID_T_PD                    ,
+    ID_T_KEBE                  ,
     ID_F_M                     ,
     ID_F_M_END = ID_F_M+50     ,
     ID_SESSION_LOG             ,
@@ -329,6 +334,7 @@ BEGIN_EVENT_TABLE(FFrame, wxFrame)
     EVT_MENU (ID_F_HISTORY,     FFrame::OnFHistory)
 
     EVT_MENU (ID_T_PD,          FFrame::OnPowderDiffraction)
+    EVT_MENU (ID_T_KEBE,        FFrame::OnXpsKEBE)
 
     EVT_MENU (ID_G_M_ZOOM,      FFrame::OnChangeMouseMode)
     EVT_MENU (ID_G_M_RANGE,     FFrame::OnChangeMouseMode)
@@ -628,7 +634,7 @@ void FFrame::set_menubar()
     data_menu->Append(-1, wxT("&XPS"), data_xps_menu);
     data_menu->AppendSeparator();
     append_mi(data_menu, ID_D_EXPORT, GET_BMP(export16),
-              wxT("&Export\tCtrl-S"), wxT("Save data to file"));
+              wxT("&Export Points\tCtrl-S"), wxT("Save data to file"));
 
     wxMenu* sum_menu = new wxMenu;
     func_type_menu_ = new wxMenu;
@@ -650,7 +656,7 @@ void FFrame::set_menubar()
     append_mi(sum_menu, ID_S_EXPORTF, GET_BMP(export16), wxT("&Export Formula"),
               wxT("Export mathematic formula to file"));
     append_mi(sum_menu, ID_S_EXPORTD, GET_BMP(export16), wxT("&Export Points"),
-              wxT("Export as points in TSV file"));
+              wxT("Export points to file"));
 
     wxMenu* fit_menu = new wxMenu;
     wxMenu* fit_method_menu = new wxMenu;
@@ -676,6 +682,8 @@ void FFrame::set_menubar()
     append_mi(tools_menu, ID_T_PD, wxBitmap(powdifpat16_xpm),
               wxT("&Powder Diffraction"),
               wxT("A tool for Pawley fitting"));
+    tools_menu->Append(ID_T_KEBE, "&XPS KE<->BE",
+                       "Requires known source energy");
 
     wxMenu* gui_menu = new wxMenu;
     wxMenu* gui_menu_mode = new wxMenu;
@@ -989,8 +997,7 @@ void FFrame::OnDataQLoad (wxCommandEvent&)
                 return;
         }
         try {
-            shared_ptr<const xylib::DataSet> d =
-                                            xylib::cached_load_file(f, "", "");
+            dataset_shared_ptr d = xylib::cached_load_file(f, "", "");
             if (d->get_block_count() > 1) {
                 wxArrayString choices;
                 for (int i = 0; i < d->get_block_count(); ++i) {
@@ -1301,6 +1308,24 @@ void FFrame::OnPowderDiffraction (wxCommandEvent&)
     PowderDiffractionDlg(this, -1).ShowModal();
 }
 
+void FFrame::OnXpsKEBE(wxCommandEvent&)
+{
+    vector<int> dd = get_selected_data_indices();
+    v_foreach(int, i, dd) {
+        Data *data = ftk->dk.data(*i);
+        double e = data->xps_source_energy();
+        if (e > 0) {
+            exec("@" + S(*i) + ": X = " + eS(e) +
+                 (data->get_x_min() > 0 ? " - x" : " + x"));
+        } else {
+            wxMessageBox("Switching between Kinetic and Binding Energy\n"
+                         "works only when the source energy is known\n"
+                         "from the data file in VAMAS or other XPS format.",
+                         "Unknown source energy", wxOK|wxICON_ERROR);
+        }
+    }
+}
+
 void FFrame::OnMenuLogStartUpdate (wxUpdateUIEvent& event)
 {
     event.Enable(ftk->get_settings()->logfile.empty());
