@@ -34,12 +34,14 @@ using fityk::Tplate;
 using fityk::Model;
 
 enum {
-    ID_plot_popup_za                = 25001,
-    ID_plot_popup_prefs                    ,
+    ID_plot_popup_za         = 25001,
+    ID_plot_popup_prefs             ,
 
-    ID_peak_popup_info                     ,
-    ID_peak_popup_del                      ,
-    ID_peak_popup_guess
+    ID_peak_popup_info              ,
+    ID_peak_popup_del               ,
+    ID_peak_popup_guess             ,
+    ID_peak_popup_edit              ,
+    ID_peak_popup_share //+15
 };
 
 
@@ -249,6 +251,9 @@ BEGIN_EVENT_TABLE(MainPlot, FPlot)
     EVT_MENU (ID_peak_popup_info,   MainPlot::OnPeakInfo)
     EVT_MENU (ID_peak_popup_del,    MainPlot::OnPeakDelete)
     EVT_MENU (ID_peak_popup_guess,  MainPlot::OnPeakGuess)
+    EVT_MENU (ID_peak_popup_edit,   MainPlot::OnPeakEdit)
+    EVT_MENU_RANGE (ID_peak_popup_share, ID_peak_popup_share+15,
+                    MainPlot::OnPeakShare)
 END_EVENT_TABLE()
 
 MainPlot::MainPlot (wxWindow *parent)
@@ -606,7 +611,7 @@ void MainPlot::prepare_peak_labels(const Model* model)
             else if (tag == "fwhm")
                 label.replace(pos, right-pos+1, f->get_fwhm(&a) ? S(a) : " ");
             else if (tag == "ib")
-                label.replace(pos, right-pos+1, f->get_iwidth(&a) ? S(a) : " ");
+                label.replace(pos, right-pos+1, f->get_ibreadth(&a) ? S(a):" ");
             else if (tag == "name")
                 label.replace(pos, right-pos+1, f->name);
             else if (tag == "br")
@@ -790,9 +795,25 @@ void MainPlot::show_peak_menu (wxMouseEvent &event)
     peak_menu.Append(ID_peak_popup_info, wxT("Show &Info"));
     peak_menu.Append(ID_peak_popup_del, wxT("&Delete"));
     peak_menu.Append(ID_peak_popup_guess, wxT("&Guess parameters"));
+    peak_menu.Append(ID_peak_popup_edit, wxT("&Edit function"));
     realt dummy;
-    peak_menu.Enable(ID_peak_popup_guess,
-                     ftk->mgr.get_function(over_peak_)->get_center(&dummy));
+    const Function* p = ftk->mgr.get_function(over_peak_);
+    peak_menu.Enable(ID_peak_popup_guess, p->get_center(&dummy));
+    int active = frame->get_sidebar()->get_active_function();
+    if (active >= 0 && active != over_peak_) {
+        const Function* a = ftk->mgr.get_function(active);
+        wxMenu *share_menu = new wxMenu;
+        for (int i = 0; i != max(a->nv(), 16); ++i) {
+            const string param = a->get_param(i);
+            if (contains_element(p->tp()->fargs, param)) {
+                share_menu->AppendCheckItem(ID_peak_popup_share+i,
+                                            "&" + s2wx(param));
+                if (a->var_name(param) == p->var_name(param))
+                    share_menu->Check(ID_peak_popup_share+i, true);
+            }
+        }
+        peak_menu.Append(-1, "&Share with %" + s2wx(a->name), share_menu);
+    }
     PopupMenu (&peak_menu, event.GetX(), event.GetY());
 }
 
@@ -816,11 +837,11 @@ void MainPlot::OnPeakGuess(wxCommandEvent&)
     realt ctr;
     if (p->get_center(&ctr)) {
         double plusmin = 0;
-        realt fwhm, iw;
+        realt fwhm, ib;
         if (p->get_fwhm(&fwhm))
             plusmin = fabs(fwhm);
-        if (p->get_iwidth(&iw) && fabs(iw) > plusmin)
-            plusmin = fabs(iw);
+        if (p->get_ibreadth(&ib) && fabs(ib) > plusmin)
+            plusmin = fabs(ib);
         plusmin = max(plusmin, 1.);
         exec(frame->get_datasets() + "guess %" + p->name + " = "
                   + frame->get_guess_string(p->tp()->name)
@@ -828,6 +849,30 @@ void MainPlot::OnPeakGuess(wxCommandEvent&)
     }
 }
 
+void MainPlot::OnPeakEdit(wxCommandEvent&)
+{
+    if (over_peak_ < 0)
+        return;
+    const Function* p = ftk->mgr.get_function(over_peak_);
+    string t = p->get_current_assignment(ftk->mgr.variables(),
+                                         ftk->mgr.parameters());
+    frame->edit_in_input(t);
+}
+
+void MainPlot::OnPeakShare(wxCommandEvent& event)
+{
+    int active = frame->get_sidebar()->get_active_function();
+    if (over_peak_ < 0 || active < 0)
+        return;
+    const Function* a = ftk->mgr.get_function(active);
+    const Function* p = ftk->mgr.get_function(over_peak_);
+    string param = a->get_param(event.GetId() - ID_peak_popup_share);
+    string lhs = "%" + p->name + "." + param;
+    if (event.IsChecked())
+        exec(lhs + " = %" + a->name + "." + param);
+    else
+        exec(lhs + " = ~{" + lhs + "}");
+}
 
 // mouse usage
 //
